Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(101)

Unified Diff: remoting/protocol/audio_writer.h

Issue 10535153: Added files for audio writers. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Fixed a small style issue Created 8 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: remoting/protocol/audio_writer.h
diff --git a/remoting/protocol/video_writer.h b/remoting/protocol/audio_writer.h
similarity index 62%
copy from remoting/protocol/video_writer.h
copy to remoting/protocol/audio_writer.h
index 12d4a9e9212f87dfadc31244c905b4b3c601bd27..1c1e1f6be22970d350e21ecf4987b6ec13ba0577 100644
--- a/remoting/protocol/video_writer.h
+++ b/remoting/protocol/audio_writer.h
@@ -2,16 +2,16 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
// VideoWriter is a generic interface used by ConnectionToClient to
// write into the video stream. ProtobufVideoWriter implements this
// interface for protobuf video streams.
#ifndef REMOTING_PROTOCOL_VIDEO_WRITER_H_
#define REMOTING_PROTOCOL_VIDEO_WRITER_H_
#include "base/basictypes.h"
#include "base/callback.h"
-#include "remoting/protocol/video_stub.h"
+#include "remoting/protocol/audio_stub.h"
namespace remoting {
namespace protocol {
@@ -19,15 +19,15 @@ namespace protocol {
class Session;
class SessionConfig;
-class VideoWriter : public VideoStub {
+class AudioWriter : public AudioStub {
Sergey Ulanov 2012/06/14 17:53:17 Don't really need this to be an abstract interface
kxing 2012/06/14 22:30:42 Done.
public:
- virtual ~VideoWriter();
+ virtual ~AudioWriter();
// The callback is called when initialization is finished. The
// parameter is set to true on success.
typedef base::Callback<void(bool)> InitializedCallback;
- static VideoWriter* Create(const SessionConfig& config);
+ static AudioWriter* Create(const SessionConfig& config);
// Initializes the writer.
virtual void Init(Session* session, const InitializedCallback& callback) = 0;
@@ -40,13 +40,13 @@ class VideoWriter : public VideoStub {
virtual bool is_connected() = 0;
protected:
- VideoWriter() { }
+ AudioWriter() { }
private:
- DISALLOW_COPY_AND_ASSIGN(VideoWriter);
+ DISALLOW_COPY_AND_ASSIGN(AudioWriter);
};
} // namespace protocol
} // namespace remoting
-#endif // REMOTING_PROTOCOL_VIDEO_WRITER_H_
+#endif // REMOTING_PROTOCOL_AUDIO_WRITER_H_

Powered by Google App Engine
This is Rietveld 408576698
@@ -2,16 +2,16 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-// VideoWriter is a generic interface used by ConnectionToClient to
-// write into the video stream. ProtobufVideoWriter implements this
-// interface for protobuf video streams.
+// AudioWriter is a generic interface used by ConnectionToClient to
+// write into the audio stream. ProtobufAudioWriter implements this
+// interface for protobuf audio streams.
-#ifndef REMOTING_PROTOCOL_VIDEO_WRITER_H_
-#define REMOTING_PROTOCOL_VIDEO_WRITER_H_
+#ifndef REMOTING_PROTOCOL_AUDIO_WRITER_H_
+#define REMOTING_PROTOCOL_AUDIO_WRITER_H_
#include "base/basictypes.h"
#include "base/callback.h"